import argparse
import pathlib

from . import standardize_java_text


def test_files(repo: pathlib.Path) -> list[pathlib.Path]:
    return list(repo.rglob('*.java'))


def standardize_in_file(
    path: pathlib.Path, inline: bool, with_javadoc: bool, with_display_name: bool,
):
    with open(path) as f:
        text = f.read()

    text_updated = standardize_java_text(text, with_javadoc, with_display_name)
    if text_updated == text:
        return

    if inline:
        with open(path, 'w') as f:
            f.write(text_updated)
    else:
        print(text_updated)


def argument_parser():
    argparser = argparse.ArgumentParser()
    argparser.add_argument('repo', type=pathlib.Path)
    argparser.add_argument('-i', action='store_true')
    argparser.add_argument('--javadoc', action='store_true')
    argparser.add_argument('--displayname', action='store_true')
    return argparser


def main():
    args = argument_parser().parse_args()

    for path in test_files(args.repo):
        standardize_in_file(
            path,
            inline=args.i,
            with_javadoc=args.javadoc,
            with_display_name=args.displayname,
        )


if __name__ == '__main__':
    main()
